pre[data-v-4c3e1e0f]{white-space:pre;border:1px solid var(--md-sys-color-outline);background:#00000040;border-radius:12px;padding:12px;overflow:auto}:host([data-theme=light]) pre[data-v-4c3e1e0f],[data-theme=light] :scope pre[data-v-4c3e1e0f]{background:#fffc}
